# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing IDL markup and linking.

    enum BarEnum { "", "bar" };
    interface Foo {
      attribute DOMString foo;
     attribute BarEnum bar;
      attribute DOMString _or;
      Promise<any> get(int a);
    };

Arguments for the Foo.get(a) method.
Parameter | Type | Nullable | Optional | Description
--- | --- | --- | --- | ---
`a` | int | ✘ | ✘ | An argument.

`Foo`, `foo`, `or`, `_or`

## Index

### Terms defined by this specification

- "", in §Unnumbered section
- "bar", in §Unnumbered section
- bar, in §Unnumbered section
- BarEnum, in §Unnumbered section
- Foo, in §Unnumbered section
- foo, in §Unnumbered section
- get(a), in §Unnumbered section
- or, in §Unnumbered section

https://heycam.github.io/webidl/#idl-DOMString Referenced in:

- Unnamed section (2)

### Terms defined by reference

- [WebIDL] defines the following terms:
  - DOMString

## References

### Normative References

[WebIDL]
  Boris Zbarsky. Web IDL. 15 December 2016. ED. URL: https://heycam.github.io/webidl/

## IDL Index

    enum BarEnum { "", "bar" };
    interface Foo {
      attribute DOMString foo;
     attribute BarEnum bar;
      attribute DOMString _or;
      Promise<any> get(int a);
    };

#enumdef-barenum Referenced in:

- Unnamed section

#foo Referenced in:

- Unnamed section

#dom-foo-foo Referenced in:

- Unnamed section

#dom-foo-or Referenced in:

- Unnamed section (2)

#dom-foo-get Referenced in:

- Unnamed section

#dom-foo-get-a-a Referenced in:

- Unnamed section